.. :changelog:

History
-------

0.2.0 (2014-11-16)
++++++++++++++++++

* Adds `--no-output` mode
* Allow to pass input via stdin

0.1.1 (2014-11-16)
++++++++++++++++++

* Bugfix in the filter plugin
* Minor bugfixes with logging statements

0.1.0 (2014-10-3)
++++++++++++++++++

* First release on PyPI.
